==> sinosun-ui-0.2.6.tgz: package/es/mstp-upload/index.js <==
import _mergeJSXProps from 'babel-helper-vue-jsx-merge-props';
import request from '../upload/request';
require('./spark-md5');
import { Base64 } from 'js-base64';
import Upload from '../upload';
import ListItemMixin from '../mixins/list-item';
import ListItem from '../list-item';
import SnToast from '../toast';

function checkExist(value) {
    return !(value === null || value === undefined);
};

// https://mstpblackbox.sinosun.com

function getFileUrl(fileId, options, type) {
    if (!options.mToken) {
        mstp.init(options);
    }
    var params_str = Base64.encodeURI(JSON.stringify({
        fileId: fileId,
        token: mstpConf.mToken
    }));
    var path = "filepreview/online";
    if (type === 'PREVIEW') {
        path = 'file/download';
    }
    return mstpConf.mFsUrl + '/' + path + '?params=' + params_str;
}

// 获取文件直接上传所需参数
function getUploadParam(file, option, direct_upload_obj) {
    if (checkExist(file.md5)) {
        direct_upload_obj.checksum = file.md5;
    }
    if (checkExist(option.anonymous)) {
        direct_upload_obj.anonymous = option.anonymous;
    }
    if (checkExist(option.encrypt)) {
        direct_upload_obj.encrypt = option.encrypt;
    }
    if (checkExist(option.imagePolicy)) {
        if (typeof option.imagePolicy === "string") {
            direct_upload_obj.imagePolicy = option.imagePolicy;
        } else {
            direct_upload_obj.imagePolicy = JSON.stringify(option.imagePolicy);
        }
    }
    var params_str = JSON.stringify(direct_upload_obj);
    return Base64.encodeURI(params_str);
};

// 获取文件分片上传所需参数
function getChunkUploadParam(fileId, chunkSeq, chunkSize, checkMd5) {
    var chunk_upload_obj = {
        fileUuid: fileId,
        chunkSeq: chunkSeq,
        chunkSize: chunkSize,
        token: mstpConf.mToken
    };

    if (checkExist(checkMd5)) {
        chunk_upload_obj.checksum = checkMd5;
    }
    var params_str = JSON.stringify(chunk_upload_obj);
    return Base64.encodeURI(params_str);
};

function getFileAndChunkMd5(file, isChunk) {
    var currentChunk = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 1;

    return new Promise(function (res, rej) {
        var blobSlice = File.prototype.slice || File.prototype.mozSlice || File.prototype.webkitSlice,
            spark = new SparkMD5.ArrayBuffer(),
            chunks = file.chunks,
            start = void 0,
            end = void 0,
            fileReader = new FileReader();

        fileReader.onload = function (e) {
            spark.append(e.target.result);
            if (isChunk) {
                var chunkBlob = blobSlice.call(file, start, end);
                var chunkSize = end - start;
                res({ chunkBlob: chunkBlob, md5: spark.end(), chunkSize: chunkSize });
            } else {
                if (currentChunk < chunks) {
                    currentChunk++;
                    readFileChunk();
                } else {
                    // spark.append(file.name); //如文件相同，名称不同,无法保留两个文件，需把文件名称加上。
                    var hash = spark.end();
                    res({ md5: hash });
                }
            }
        };

        fileReader.onerror = function (e) {
            console.log('[upload info]\u6587\u4EF6\u8BFB\u53D6\u5931\u8D25\u503C');
            rej(e);
        };

        var readFileChunk = function readFileChunk() {
            start = (currentChunk - 1) * mstpConf.chunkSize;
            end = start + mstpConf.chunkSize > file.size ? file.size : start + mstpConf.chunkSize;
            fileReader.readAsArrayBuffer(blobSlice.call(file, start, end));
        };

        readFileChunk();
    })['catch'](function (err) {
        console.log('[upload info] ' + err);
    });
}

var mstpConf = {
    chunkSize: 4 << 20,
    anonymous: 1,
    mFsUrl: ''
};
var mstp = {
    init: function init(option) {
        if (!option.appId || !option.mstpId || !option.mFsUrl || !option.exptime || !option.creationTime || !option.signature) return;
        mstpConf.mAppId = option.appId;
        mstpConf.mMstpId = option.mstpId;
        mstpConf.mFsUrl = option.mFsUrl;
        var tokenObj = {
            appId: option.appId,
            mstpId: option.mstpId,
            exptime: option.exptime,
            creationTime: option.creationTime,
            signature: option.signature
        };
        mstpConf.mToken = Base64.encodeURI(JSON.stringify(tokenObj));
    },
    uploadDeirect: function uploadDeirect(options) {
        getFileAndChunkMd5(options.file, false).then(function (data) {
            var md5 = data.md5,
                file = options.file;

            file.md5 = md5;
            var direct_upload_obj = {
                token: mstpConf.mToken,
                fileName: file.name,
                mstpId: mstpConf.mMstpId
            };
            var requestParams = {
                params: getUploadParam(file, options, direct_upload_obj) //to be set later
            };
            request({
                action: mstpConf.mFsUrl + "/file/upload",
                data: requestParams,
                file: options.file,
                onProgress: options.onProgress,
                onSuccess: options.onSuccess,
                onError: options.onError
            });
        });
    },
    uploadChunk: function uploadChunk(file, options) {
        getFileAndChunkMd5(file.originFileObj || file, true, file.currentChunk).then(function (data) {
            var chunkBlob = data.chunkBlob,
                md5 = data.md5,
                chunkSize = data.chunkSize;

            var requestParams = {
                params: getChunkUploadParam(file.uid, file.currentChunk, chunkSize, md5), //to be set later
                chunk: file.currentChunk - 1,
                chunks: file.chunks
            };
            request({
                action: mstpConf.mFsUrl + "/file/chunk/upload",
                data: requestParams,
                file: chunkBlob,
                onProgress: options.onProgress,
                onSuccess: options.onSuccess,
                onError: options.onError
            });
        }, function (e) {
            console.log('[upload info] e');
        });
    },
    mergeChunks: function mergeChunks(file, options, vm) {
        var direct_upload_obj = {
            fileUuid: file.uid,
            chunkCount: file.chunks,
            token: mstpConf.mToken,
            fileName: file.name,
            mstpId: mstpConf.mMstpId,
            anonymous: 1
        };
        var requestParams = {
            params: getUploadParam(file, options, direct_upload_obj)
        };
        request({
            action: mstpConf.mFsUrl + "/file/chunk/merge",
            data: requestParams,
            headers: { 'content-Type': 'application/x-www-form-urlencoded' },
            onProgress: options.onProgress,
            onSuccess: function onSuccess(result) {
                vm.loadEnd(file, result);
            },
            onError: options.onError
        });
    },
    upload: function upload(options) {
        var chunkSize = mstpConf.chunkSize;
        var file = options.file;
        if (!file || !file.size || file.size <= 0 || !file.name) {
            console.log('[upload info] \u6587\u4EF6\u540D\u79F0\u6216\u8005\u6587\u4EF6\u683C\u5F0F\u975E\u6CD5\uFF0C\u8BF7\u786E\u8BA4\u6587\u4EF6\u540D\u6CA1\u6709\u7279\u6B8A\u5B57\u7B26\u6216\u8005\u6587\u4EF6\u540D\u8D85\u957F');
            return;
        }
        console.log('[upload info] start to upload file ' + file.name + ', file.size:', file.size, 'chunkSize:', chunkSize);
        if (file.size < chunkSize) {
            mstp.uploadDeirect(options);
        } else {
            file.chunkSize = chunkSize;
            file.chunks = Math.ceil(file.size / chunkSize);
            getFileAndChunkMd5(options.file, false).then(function (data) {
                var md5 = data.md5;

                file.md5 = md5;
                file.currentChunk = 1;
                mstp.uploadChunk(options.file, options);
            });
        }
    }
};

var MstpUpload = {
    mixins: [ListItemMixin],
    props: {
        rightIcon: {
            type: String,
            'default': 'clip-add'
        },
        listType: {
            type: String,
            'default': 'text'
        }, // or pictrue
        readOnly: {
            type: Boolean,
            'default': false
        },
        showPreviewIcon: {
            type: Boolean,
            'default': function _default() {
                return true;
            }
        },
        uploadBefore: Function,
        succFunction: Function,
        showUploadList: {
            type: Boolean,
            'default': true
        },
        defaultFileList: {
            type: Array,
            'default': function _default() {
                return [];
            }
        },
        initOption: {
            type: Object,
            'default': null
        }
    },
    data: function data() {
        return {
            fileList: [].concat(this.defaultFileList)
        };
    },
    created: function created() {
        mstp.init(this.initOption);
    },

    methods: {
        reBeforeUpload: function reBeforeUpload() {
            if (!mstpConf.mToken) {
                this.$toast("请先初始化组件");
                return false;
            }
            if (!this.uploadBefore) {
                return true;
            }
            var result = this.uploadBefore(file, files);
            if (result === false) {
                return false;
            } else if (result && result.then) {
                return result;
            }
            return true;
        },
        onRightIconClick: function onRightIconClick() {
            if (!this.readOnly) {
                this.$refs.Upload.onClick();
            }
        },
        onPreview: function onPreview(file) {
            // this.$emit("onPreview", file);
        },
        onRemove: function onRemove(file, index) {
            this.fileList.splice(index, 1);
        },
        onStart: function onStart(file, fileList) {
            this.fileList.push(file);
        },
        onProgress: function onProgress(info, file) {
            var percent = file.percent || 0;
            var loaded = info.loaded;
            if (percent >= 100) return;
            if (file.currentChunk || file.originFileObj.currentChunk) {
                file.currentChunk = file.originFileObj.currentChunk;
                file.chunkSize = file.originFileObj.chunkSize;
                file.chunks = file.originFileObj.chunks;
                loaded = (file.currentChunk - 1) * file.chunkSize + loaded;
            }
            file.percent = parseInt(loaded * 100 / file.size);
            this.$emit('onProgress', file);
        },
        onError: function onError() {},
        onSuccess: function onSuccess(file, result) {
            var ret = JSON.parse(Base64.decode(result.data));
            if (!file.chunks || file.chunks === 1) {
                this.loadEnd(file, ret);
                return;
            }
            if (file.currentChunk < file.chunks) {
                file.currentChunk++;
                file.originFileObj && file.originFileObj.currentChunk++;
                mstp.uploadChunk(file, file.options);
            } else {
                mstp.mergeChunks(file, file.options, this);
            }
        },
        loadEnd: function loadEnd(file, result) {
            var fileId = result.fileId;
            file.status = 'uploaded';
            file.dlUrl = getFileUrl(fileId, mstpConf);
            file.previewUrl = getFileUrl(fileId, mstpConf, "PREVIEW");
            this.$emit('onSuccess', file, fileId);
            return;
        }
    },
    render: function render() {
        var h = arguments[0];

        var uploadProps = {
            props: {
                listType: this.listType,
                readOnly: this.readOnly,
                showPreviewIcon: this.showPreviewIcon,
                showUploadList: this.showUploadList,
                defaultFileList: this.defaultFileList,
                customRequest: mstp.upload,
                beforeUpload: this.reBeforeUpload
            },
            on: {
                onRemove: this.onRemove,
                onPreview: this.onPreview,
                onStart: this.onStart,
                onError: this.onError,
                onProgress: this.onProgress,
                onSuccess: this.onSuccess
            }
        };
        var itemProps = {
            props: {
                title: this.$props.title,
                value: this.fileList.length ? this.fileList.length + '张' : '',
                valuePosition: 'left',
                labelNumber: 5
            }
        };
        if (!this.readOnly) {
            itemProps['props']['rightIcon'] = this.$props.rightIcon;
        }
        return h(
            'div',
            { 'class': 'sn-mstp-upload' },
            [h(ListItem, _mergeJSXProps([itemProps, {
                on: {
                    'right-icon-click': this.onRightIconClick
                }
            }])), this.$slots.top ? this.$slots.top : null, h(Upload, _mergeJSXProps([uploadProps, { ref: 'Upload' }])), this.$slots.bottom ? this.$slots.bottom : null]
        );
    }
};

MstpUpload.getFileUrl = getFileUrl;

export default MstpUpload;

==> sinosun-ui-0.3.6.tgz: package/es/mstp-upload/index.js <==
import _mergeJSXProps from 'babel-helper-vue-jsx-merge-props';
import request from '../upload/request';
var SparkMD5 = require('./spark-md5');
import { Base64 } from 'js-base64';
import Upload from '../upload';
import ListItemMixin from '../mixins/list-item';
import ListItem from '../list-item';
import SnToast from '../toast';

function checkExist(value) {
    return !(value === null || value === undefined);
};

// https://mstpblackbox.sinosun.com

function getFileUrl(fileId, options, type) {
    if (!options.mToken) {
        mstp.init(options);
    }
    var params_str = Base64.encodeURI(JSON.stringify({
        fileId: fileId,
        token: mstpConf.mToken
    }));
    var path = "file/download";
    if (type === 'PREVIEW') {
        path = 'filepreview/online';
    }
    return mstpConf.mFsUrl + '/' + path + '?params=' + params_str;
}

// 获取文件直接上传所需参数
function getUploadParam(file, option, direct_upload_obj) {
    if (checkExist(file.md5)) {
        direct_upload_obj.checksum = file.md5;
    }
    if (checkExist(option.anonymous)) {
        direct_upload_obj.anonymous = option.anonymous;
    }
    if (checkExist(option.encrypt)) {
        direct_upload_obj.encrypt = option.encrypt;
    }
    if (checkExist(option.imagePolicy)) {
        if (typeof option.imagePolicy === "string") {
            direct_upload_obj.imagePolicy = option.imagePolicy;
        } else {
            direct_upload_obj.imagePolicy = JSON.stringify(option.imagePolicy);
        }
    }
    var params_str = JSON.stringify(direct_upload_obj);
    return Base64.encodeURI(params_str);
};

// 获取文件分片上传所需参数
function getChunkUploadParam(fileId, chunkSeq, chunkSize, checkMd5) {
    var chunk_upload_obj = {
        fileUuid: fileId,
        chunkSeq: chunkSeq,
        chunkSize: chunkSize,
        token: mstpConf.mToken
    };

    if (checkExist(checkMd5)) {
        chunk_upload_obj.checksum = checkMd5;
    }
    var params_str = JSON.stringify(chunk_upload_obj);
    return Base64.encodeURI(params_str);
};

function getFileAndChunkMd5(file, isChunk) {
    var currentChunk = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 1;

    return new Promise(function (res, rej) {
        var blobSlice = File.prototype.slice || File.prototype.mozSlice || File.prototype.webkitSlice,
            spark = new SparkMD5.ArrayBuffer(),
            chunks = file.chunks,
            start = void 0,
            end = void 0,
            fileReader = new FileReader();

        fileReader.onload = function (e) {
            spark.append(e.target.result);
            if (isChunk) {
                var chunkBlob = blobSlice.call(file, start, end);
                var chunkSize = end - start;
                res({ chunkBlob: chunkBlob, md5: spark.end(), chunkSize: chunkSize });
            } else {
                if (currentChunk < chunks) {
                    currentChunk++;
                    readFileChunk();
                } else {
                    // spark.append(file.name); //如文件相同，名称不同,无法保留两个文件，需把文件名称加上。
                    var hash = spark.end();
                    res({ md5: hash });
                }
            }
        };

        fileReader.onerror = function (e) {
            console.log('[upload info]\u6587\u4EF6\u8BFB\u53D6\u5931\u8D25\u503C');
            rej(e);
        };

        var readFileChunk = function readFileChunk() {
            start = (currentChunk - 1) * mstpConf.chunkSize;
            end = start + mstpConf.chunkSize > file.size ? file.size : start + mstpConf.chunkSize;
            fileReader.readAsArrayBuffer(blobSlice.call(file, start, end));
        };

        readFileChunk();
    })['catch'](function (err) {
        console.log('[upload info] ' + err);
    });
}

var mstpConf = {
    chunkSize: 4 << 20,
    anonymous: 1,
    mFsUrl: ''
};
var mstp = {
    init: function init(option) {
        option = option || {};
        if (!option.appId || !option.mstpId || !option.mFsUrl || !option.exptime || !option.creationTime || !option.signature) return;
        mstpConf.mAppId = option.appId;
        mstpConf.mMstpId = option.mstpId;
        mstpConf.mFsUrl = option.mFsUrl;
        var tokenObj = {
            appId: option.appId,
            mstpId: option.mstpId,
            exptime: option.exptime,
            creationTime: option.creationTime,
            signature: option.signature
        };
        mstpConf.mToken = Base64.encodeURI(JSON.stringify(tokenObj));
    },
    uploadDeirect: function uploadDeirect(options) {
        getFileAndChunkMd5(options.file, false).then(function (data) {
            var md5 = data.md5,
                file = options.file;

            file.md5 = md5;
            var direct_upload_obj = {
                token: mstpConf.mToken,
                fileName: file.name,
                mstpId: mstpConf.mMstpId
            };
            var requestParams = {
                params: getUploadParam(file, options, direct_upload_obj) //to be set later
            };
            request({
                action: mstpConf.mFsUrl + "/file/upload",
                data: requestParams,
                file: options.file,
                onProgress: options.onProgress,
                onSuccess: options.onSuccess,
                onError: options.onError
            });
        });
    },
    uploadChunk: function uploadChunk(file, options) {
        getFileAndChunkMd5(file.originFileObj || file, true, file.currentChunk).then(function (data) {
            var chunkBlob = data.chunkBlob,
                md5 = data.md5,
                chunkSize = data.chunkSize;

            var requestParams = {
                params: getChunkUploadParam(file.uid, file.currentChunk, chunkSize, md5), //to be set later
                chunk: file.currentChunk - 1,
                chunks: file.chunks
            };
            request({
                action: mstpConf.mFsUrl + "/file/chunk/upload",
                data: requestParams,
                file: chunkBlob,
                onProgress: options.onProgress,
                onSuccess: options.onSuccess,
                onError: options.onError
            });
        }, function (e) {
            console.log('[upload info] e');
        });
    },
    mergeChunks: function mergeChunks(file, options, vm) {
        var direct_upload_obj = {
            fileUuid: file.uid,
            chunkCount: file.chunks,
            token: mstpConf.mToken,
            fileName: file.name,
            mstpId: mstpConf.mMstpId,
            anonymous: 1
        };
        var requestParams = {
            params: getUploadParam(file, options, direct_upload_obj)
        };
        request({
            action: mstpConf.mFsUrl + "/file/chunk/merge",
            data: requestParams,
            headers: { 'content-Type': 'application/x-www-form-urlencoded' },
            onProgress: options.onProgress,
            onSuccess: function onSuccess(result) {
                vm.loadEnd(file, result);
            },
            onError: options.onError
        });
    },
    upload: function upload(options) {
        var chunkSize = mstpConf.chunkSize;
        var file = options.file;
        if (!file || !file.size || file.size <= 0 || !file.name) {
            console.log('[upload info] \u6587\u4EF6\u540D\u79F0\u6216\u8005\u6587\u4EF6\u683C\u5F0F\u975E\u6CD5\uFF0C\u8BF7\u786E\u8BA4\u6587\u4EF6\u540D\u6CA1\u6709\u7279\u6B8A\u5B57\u7B26\u6216\u8005\u6587\u4EF6\u540D\u8D85\u957F');
            return;
        }
        console.log('[upload info] start to upload file ' + file.name + ', file.size:', file.size, 'chunkSize:', chunkSize);
        if (file.size < chunkSize) {
            mstp.uploadDeirect(options);
        } else {
            file.chunkSize = chunkSize;
            file.chunks = Math.ceil(file.size / chunkSize);
            getFileAndChunkMd5(options.file, false).then(function (data) {
                var md5 = data.md5;

                file.md5 = md5;
                file.currentChunk = 1;
                mstp.uploadChunk(options.file, options);
            });
        }
    }
};

var MstpUpload = {
    mixins: [ListItemMixin],
    props: {
        rightIcon: {
            type: String,
            'default': 'clip-add'
        },
        listType: {
            type: String,
            'default': 'text'
        }, // or pictrue
        readOnly: {
            type: Boolean,
            'default': false
        },
        showPreviewIcon: {
            type: Boolean,
            'default': function _default() {
                return true;
            }
        },
        uploadBefore: Function,
        succFunction: Function,
        showUploadList: {
            type: Boolean,
            'default': true
        },
        defaultFileList: {
            type: Array,
            'default': function _default() {
                return [];
            }
        },
        initOption: {
            type: Object,
            'default': function _default() {}
        },
        uploadOption: {
            type: Object,
            'default': function _default() {}
        }
    },
    data: function data() {
        return {
            fileList: [].concat(this.defaultFileList)
        };
    },

    watch: {
        // mstp 初始化处理 数据变更 重新初始化
        initOption: function initOption(newVal) {
            mstp.init(newVal);
        }
    },
    created: function created() {
        mstp.init(this.initOption);
    },

    methods: {
        reBeforeUpload: function reBeforeUpload(file, files) {
            if (!mstpConf.mToken) {
                this.$toast("请先初始化组件");
                return false;
            }
            if (!this.uploadBefore) {
                return true;
            }
            var result = this.uploadBefore(file, files);
            if (result === false) {
                return false;
            } else if (result && result.then) {
                return result;
            }
            return true;
        },
        onRightIconClick: function onRightIconClick() {
            if (!this.readOnly) {
                this.$refs.Upload.onClick();
            }
        },
        onPreview: function onPreview(file) {
            this.$emit("onPreview", file);
        },
        onDownload: function onDownload(file) {
            this.$emit("onDownload", file);
        },
        onRemove: function onRemove(file, index) {
            this.removeSuccess(file);
            this.$emit('onRemove', file, index);
        },

        // 删除当前开始上传成功列表的数据
        removeSuccess: function removeSuccess(file) {
            var index = (this.fileList || []).findIndex(function (item) {
                return item.uid === file.uid;
            });
            if (index !== -1) {
                this.fileList.splice(index, 1);
            }
        },
        onStart: function onStart(file, fileList) {},
        onProgress: function onProgress(info, file) {
            var loaded = info.loaded;
            if (file.currentChunk || file.originFileObj.currentChunk) {
                file.currentChunk = file.originFileObj.currentChunk;
                file.chunkSize = file.originFileObj.chunkSize;
                file.chunks = file.originFileObj.chunks;
                loaded = (file.currentChunk - 1) * file.chunkSize + loaded;
            }
            file.percent = parseInt(loaded * 100 / file.size);
            this.$emit('onProgress', file);
        },
        onError: function onError() {},
        onSuccess: function onSuccess(file, result) {
            var ret = JSON.parse(Base64.decode(result.data));
            // 上传成功
            if (!file.chunks || file.chunks === 1) {
                this.loadEnd(file, ret);
                return;
            }
            if (file.currentChunk < file.chunks) {
                file.currentChunk++;
                file.originFileObj && file.originFileObj.currentChunk++;
                mstp.uploadChunk(file, file.options);
            } else {
                mstp.mergeChunks(file, file.options, this);
            }
        },
        loadEnd: function loadEnd(file, result) {
            this.fileList.push(file);
            var fileId = result.fileId;
            file.status = 'uploaded';
            file.dlUrl = getFileUrl(fileId, mstpConf);
            file.previewUrl = getFileUrl(fileId, mstpConf, "PREVIEW");
            this.$emit('onSuccess', file, fileId);
            return;
        },

        // 获取是否上传完成
        getUploadComplete: function getUploadComplete() {
            return this.$refs.Upload.getUploadComplete();
        }
    },
    render: function render() {
        var h = arguments[0];

        var uploadProps = {
            props: {
                listType: this.listType,
                readOnly: this.readOnly,
                uploadOption: this.uploadOption,
                showPreviewIcon: this.showPreviewIcon,
                showUploadList: this.showUploadList,
                defaultFileList: this.defaultFileList,
                customRequest: mstp.upload,
                beforeUpload: this.reBeforeUpload
            },
            on: {
                onRemove: this.onRemove,
                onPreview: this.onPreview,
                onDownload: this.onDownload,
                onStart: this.onStart,
                onError: this.onError,
                onProgress: this.onProgress,
                onSuccess: this.onSuccess
            }
        };
        var itemProps = {
            props: {
                title: this.$props.title,
                value: this.fileList.length ? this.fileList.length + '张' : '',
                valuePosition: this.$props.valuePosition || 'left',
                labelNumber: this.$props.labelNumber || 5
            }
        };

        if (!this.readOnly) {
            itemProps['props']['rightIcon'] = this.$props.rightIcon;
        }

        var itemListProps = {
            props: {
                title: ' ',
                valuePosition: this.$props.valuePosition || 'left',
                labelNumber: this.$props.labelNumber || 5
            }
        };
        return h(
            'div',
            { 'class': 'sn-mstp-upload' },
            [h(ListItem, _mergeJSXProps([itemProps, {
                on: {
                    'right-icon-click': this.onRightIconClick
                }
            }])), h(
                ListItem,
                _mergeJSXProps([itemListProps, { 'class': 'upload-item-con' }]),
                [h(
                    'div',
                    { 'class': 'upload-con' },
                    [this.$slots.top ? this.$slots.top : null, h(Upload, _mergeJSXProps([uploadProps, { ref: 'Upload' }])), this.$slots.bottom ? this.$slots.bottom : null]
                )]
            )]
        );
    }
};

MstpUpload.getFileUrl = getFileUrl;

export default MstpUpload;
